@@ -88,10 +88,11 @@ def GetFirstEntry():
 ##  Process the data, generate movement indication
 ###########################################################################
 def ProcessData(ProcessAll=False):  #DERIVATION (ABLEITUNG)
+    if(data.debug==1): print "Process Data (Process whole array:", ProcessAll,  ")"
     lastmovebeforegraph=0 
     if(ProcessAll==True): start=0 #process whole array
     else: start=records.Index-data.Derivation-1 #process only last (changed) records
-    
+    if(data.debug==1): print "Process entry", start, "to", records.Index-data.Derivation
     lastindexovertrigger=records.arrData[4][start]
     for i in range(start, records.Index-data.Derivation):     
         t=i*(records.Sampling_interval*records.Value_smoothing)/1000
@@ -119,7 +120,8 @@ def ProcessData(ProcessAll=False):  #DERIVATION (ABLEITUNG)
 ## Show (refreshs) the graph.
 ## the first parameter indcates on which window it will be drawn
 ###########################################################################
-def GenerateGraph(self,  QtGui):
+def DrawGraph(self,  QtGui):
+    if(data.debug==1): print "Draw Graph data"
 
     Xscale=data.arrXscale[data.Xscale]
     decade=360/Xscale
