@@ -182,12 +182,12 @@ def MeasurementTimerLoop(): #(interval: sampling*sample_smoothing*value_smoothin
 #        data.GraphStart=max(GraphLen-779, 0)
         
         data.ScrollToEnd=True
-        ShowGraph(RecordWindow)    
+        GenerateGraph(RecordWindow)    
     
         if(records.Index==records.MaxArrayDataLen-1): 
             print "Stopped, array is full"
             data.Status="Stopped, array is full!"
-            QtGui.QMessageBox.warning(RecordWindow, 'Memory is full!', "You reached the end of the recording capacity (24h)!\nThe recording stops now.", QtGui.QMessageBox.Ok)
+            QtGui.QMessageBox.warning(RecordWindow, 'Memory is full!', "You reached the end of the recording capacity!\nThe recording stops now.", QtGui.QMessageBox.Ok)
 #            RecordWindow.StopMeasurement()
             StopMeasurement() #but keep alarm active!
     
@@ -251,7 +251,7 @@ def InitMeasurement():
     GetFirstEntry()
     WriteIntoRecordFile()
    
-    ShowGraph(RecordWindow)
+    GenerateGraph(RecordWindow)
     RecordWindow.UpdateScreen()
     
     RecordWindow.ui.CanvasWidget.show()
@@ -682,13 +682,13 @@ class frmRecordWindow(QMainWindow):
 
     def ZoomIn(self):
         Zoom(+1)
-        ShowGraph(self)
+        GenerateGraph(self)
         
 
 
     def ZoomOut(self):
         Zoom(-1)
-        ShowGraph(self)
+        GenerateGraph(self)
 
 
 
@@ -698,7 +698,7 @@ class frmRecordWindow(QMainWindow):
         if(data.Trigger==data.maxTrigger): self.ui.bRaiseTrigger.setEnabled(False)
         else: self.ui.bRaiseTrigger.setEnabled(True)
          
-        ShowGraph(self)
+        GenerateGraph(self)
         
         
         
@@ -708,7 +708,7 @@ class frmRecordWindow(QMainWindow):
         if(data.Trigger==0): self.ui.bLowerTrigger.setEnabled(False)
         else: self.ui.bLowerTrigger.setEnabled(True)
          
-        ShowGraph(self)
+        GenerateGraph(self)
 
 
 
@@ -915,7 +915,7 @@ class frmViewWindow(QMainWindow):
 #        data.ChangesInGraph=True #Make sure it only gets refreshed once
 
 
-        ShowGraph(self)
+        GenerateGraph(self)
       
         
         
@@ -961,7 +961,7 @@ class frmViewWindow(QMainWindow):
 #        data.ChangesInGraph=True #Make sure it only gets refreshed once
         
         
-        ShowGraph(self)
+        GenerateGraph(self)
         
         
         
@@ -985,7 +985,7 @@ class frmViewWindow(QMainWindow):
 #        data.ChangesInGraph=True #Make sure it only gets refreshed once
         
         
-        ShowGraph(self)
+        GenerateGraph(self)
 
         
     ###########################################################################
@@ -994,7 +994,7 @@ class frmViewWindow(QMainWindow):
     def RaiseTrigger(self):   
         MoveTrigger(+1)
         
-        ShowGraph(self)
+        GenerateGraph(self)
 
 
     ###########################################################################
@@ -1003,7 +1003,7 @@ class frmViewWindow(QMainWindow):
     def LowerTrigger(self):     
         MoveTrigger(-1)
         
-        ShowGraph(self)
+        GenerateGraph(self)
     
         
 #    ###########################################################################
@@ -1508,9 +1508,9 @@ class frmAlarmTimeWindow(QMainWindow):
         SetAlarm() #set alarm for the last possible time
         InitMeasurement()
         
-#        RecordWindow.show()
-#        AlarmTimeWindow.hide()
-#        RecordWindow.UpdateScreenStart()
+        RecordWindow.show()
+        AlarmTimeWindow.hide()
+        RecordWindow.UpdateScreenStart()
 #        RecordWindowCanvas.show()
 
 
@@ -1637,7 +1637,8 @@ class DisplayStatusDaemon:
                                            path='/com/nokia/mce/signal',
                                         signal_name='display_status_ind',
                                         dbus_interface='com.nokia.mce.signal')
-            print "DisplayStatusDaemon started"
+                                        
+            if(data.debug==1): print "DisplayStatusDaemon started"
 
 
 
@@ -1683,6 +1684,7 @@ class MyCanvas(QtGui.QWidget):
     ## 
     ###########################################################################
     def paintEvent(self, event):
+        if(data.debug==1): print "Paint Event"
         if(data.DisplayIsOn==False):
             if(data.debug==1): print "-> Do not redraw, Display is off!"
             return
@@ -1692,7 +1694,7 @@ class MyCanvas(QtGui.QWidget):
             else: ViewWindow.ui.ScrollArea.ensureVisible(data.GraphBitMapLen+100, 0, 0 , 0)
             data.ScrollToEnd=False
 
-#        GenerateGraph(self,  QtGui)
+#        DrawGraph(self,  QtGui)
 
         paint = QtGui.QPainter()
         paint.begin(self)
@@ -1712,11 +1714,12 @@ class MyCanvas(QtGui.QWidget):
 ###########################################################################
 ## 
 ###########################################################################        
-def ShowGraph(self):
+def GenerateGraph(self):
+    if(data.debug==1): print "Generate Graph"
     if(data.DisplayIsOn==False):
         if(data.debug==1): print "-> Do not update graph, Display is off!"
         return
-        
+
     Xscale=data.arrXscale[data.Xscale]
 #        data.GraphBitMapLen=max((records.LastIndex+5)/Xscale + 2 ,  770)
     data.GraphBitMapLen=max((records.LastIndex+5)/Xscale + 2 ,  735)
@@ -1726,7 +1729,7 @@ def ShowGraph(self):
     
     data.GraphBitMap = QtGui.QPixmap(data.GraphBitMapLen, data.GraphBitMapHeight) #create bitmap for graph
     
-    GenerateGraph(data.GraphBitMap,  QtGui) # draw graph
+    DrawGraph(data.GraphBitMap,  QtGui) # draw graph
     
 #    ViewWindowCanvas.setGeometry(0, 0, data.GraphBitMapLen, data.GraphBitMapHeight)  #set size of canvas to graph 
     self.Canvas.setGeometry(0, 0, data.GraphBitMapLen, data.GraphBitMapHeight)  #set size of canvas to graph 
